"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/es.parse-int.js");

var _react = require("react");

var _dayjs = _interopRequireDefault(require("dayjs"));

var _config = require("../../config");

var _bind = _interopRequireDefault(require("classnames/bind"));

var _css = _interopRequireDefault(require("./css"));

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let _s = _bind.default.bind(_css.default);

function calcTicksTxt(startDate, endDate) {
  const day_span = 24 * 60 * 60 * 1000;
  let f_start_date = (0, _dayjs.default)(startDate),
      f_end_date = (0, _dayjs.default)(endDate),
      f_start_date_hour = f_start_date.startOf('hour'),
      f_end_date_hour = f_end_date.startOf('hour'),
      temp_date,
      begin_of_2021 = (0, _dayjs.default)('2021-01-01').valueOf(),
      hour_arr = [],
      day_arr = [];
  let t1 = f_start_date_hour.add(.5, 'hour');
  temp_date = t1.isAfter(f_start_date) ? t1 : f_start_date_hour.add(1, 'hour');

  while (temp_date.valueOf() < f_end_date.valueOf()) {
    if ((temp_date.valueOf() - begin_of_2021) % day_span === 0) {
      day_arr.push({
        offset_ms: temp_date.valueOf() - f_start_date.valueOf(),
        str: temp_date.format('MM/DD'),
        type: 'date'
      });
      hour_arr.push({
        offset_ms: temp_date.valueOf() - f_start_date.valueOf(),
        str: temp_date.format('HH:mm'),
        type: 'time-00am'
      });
    } else {
      hour_arr.push({
        offset_ms: temp_date.valueOf() - f_start_date.valueOf(),
        str: temp_date.format('HH:mm'),
        type: 'time'
      });
    }

    temp_date = temp_date.add(.5, 'hour');
  }

  return {
    hour_arr,
    day_arr
  };
}

const XAxisSvg = _ref => {
  let {
    svgWith,
    showPercent,
    showStartPercent,
    data,
    msWidth,
    startDate,
    endDate
  } = _ref;
  const tick_span = 1800000;
  const f_start_date = (0, _dayjs.default)(startDate);
  const f_end_date = (0, _dayjs.default)(endDate);
  const duration = f_end_date.valueOf() - f_start_date.valueOf();
  const offset_length = duration * msWidth * showStartPercent;
  const {
    HOUR_TICKS,
    DAY_TICKS
  } = (0, _react.useMemo)(() => {
    let {
      hour_arr,
      day_arr
    } = calcTicksTxt(startDate, endDate);
    return {
      HOUR_TICKS: hour_arr,
      DAY_TICKS: day_arr
    };
  }, [startDate, endDate]);
  const HOUR_TICKS_LEN = HOUR_TICKS.length;
  const hour_ticks_num = parseInt(showPercent * HOUR_TICKS_LEN);
  const hour_step_offset = parseInt(hour_ticks_num / _config.HOUR_TICKS_MAX) + 1;
  const line_step_offset = parseInt(hour_ticks_num / _config.LINE_TICKS_MAX) + 1;

  const drawHourTickLine = () => {
    return HOUR_TICKS.map((obj, i) => {
      if (i % line_step_offset === 0 || obj.type === 'time-00am') {
        return (0, _jsxRuntime.jsx)("line", {
          x1: _config.MARGIN_LEFT + msWidth * obj.offset_ms - offset_length,
          y1: 0,
          x2: _config.MARGIN_LEFT + msWidth * obj.offset_ms - offset_length,
          y2: obj.type === 'time-00am' ? 8 : 5,
          strokeWidth: obj.type === 'time-00am' ? 2 : 1,
          strokeOpacity: "1",
          stroke: obj.type === 'time-00am' ? '#ff5252' : '#c7cad5'
        }, i);
      } else {
        return null;
      }
    });
  };

  const drawHourTickTxt = () => {
    return HOUR_TICKS.map((obj, i) => {
      if (i % hour_step_offset === 0) {
        return (0, _jsxRuntime.jsx)("text", {
          x: _config.MARGIN_LEFT + msWidth * obj.offset_ms - offset_length,
          y: "20",
          fill: "#000",
          fillOpacity: "0.45",
          fontSize: "11",
          textAnchor: "middle",
          children: obj.str
        }, "txt-".concat(i));
      } else {
        return null;
      }
    });
  };

  const DAY_TICKS_LEN = DAY_TICKS.length;
  const day_ticks_num = parseInt(showPercent * DAY_TICKS_LEN);
  const day_step_offset = parseInt(day_ticks_num / _config.DAY_TICKS_MAX) + 1;

  const drawDayTickTxt = () => {
    return DAY_TICKS.map((obj, i) => {
      if (i % day_step_offset === 0) {
        return (0, _jsxRuntime.jsx)("text", {
          x: _config.MARGIN_LEFT + msWidth * obj.offset_ms - offset_length,
          y: "38",
          fill: "#000",
          fillOpacity: "0.7",
          fontSize: "12",
          fontWeight: "bold",
          textAnchor: "middle",
          children: obj.str
        }, "day-txt-".concat(i));
      } else {
        return null;
      }
    });
  };

  return (0, _jsxRuntime.jsxs)("div", {
    className: _s('axis-wrap'),
    children: [(0, _jsxRuntime.jsxs)("svg", {
      width: svgWith,
      height: "63",
      children: [drawHourTickLine(), drawHourTickTxt(), drawDayTickTxt()]
    }), (0, _jsxRuntime.jsx)("div", {
      className: _s('block-left'),
      style: {
        width: "".concat(_config.MARGIN_LEFT, "px")
      }
    })]
  });
};

var _default = XAxisSvg;
exports.default = _default;