"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

require("core-js/modules/es.array.reduce.js");

var _react = require("react");

var _config = require("./config");

var _dayjs = _interopRequireDefault(require("dayjs"));

var _reactCalendar = _interopRequireDefault(require("react-calendar"));

var _ChartSvg = _interopRequireDefault(require("./coms/ChartSvg"));

var _SummarySvg = _interopRequireDefault(require("./coms/SummarySvg"));

var _DragSlider = _interopRequireDefault(require("./coms/DragSlider"));

var _XAxisSvg = _interopRequireDefault(require("./coms/XAxisSvg"));

var _bind = _interopRequireDefault(require("classnames/bind"));

var _css = _interopRequireDefault(require("./css"));

require("./style.css");

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let _s = _bind.default.bind(_css.default);

const GanttReact = _ref => {
  let {
    config
  } = _ref;
  const {
    title,
    nodes,
    width,
    height
  } = config;
  const f_start_date = (0, _dayjs.default)(config.startDate);
  const f_end_date = (0, _dayjs.default)(config.endDate);
  const [showPercent, setShowPercent] = (0, _react.useState)(config.showPercent);
  const [showStartPercent, setShowStartPercent] = (0, _react.useState)(config.showStartPercent);
  const [startDate, setStartDate] = (0, _react.useState)(f_start_date.toDate());
  const [endDate, setEndDate] = (0, _react.useState)(f_end_date.toDate());
  const [showCalendar, setShowCalendar] = (0, _react.useState)(false);
  const columnWidth = (width - _config.MARGIN_LEFT) / (_config.GRID_COLUMN_NUM * showPercent);
  const msWidth = (width - _config.MARGIN_LEFT) / (((0, _dayjs.default)(endDate).valueOf() - (0, _dayjs.default)(startDate).valueOf()) * showPercent);
  const svgWith = width / showPercent;

  const onDragging = data => {};

  config.nodes = (0, _react.useMemo)(() => {
    let start_y = 0;
    return nodes.map(node => {
      node.row_height = !!node.averageTime ? _config.GRID_ROW_HEIGHT : _config.GRID_ROW_HEIGHT - _config.AVERAGE_TIME_RECT_HEIGHT;
      node.start_y = start_y;
      start_y += node.row_height;
      return node;
    });
  }, []);
  config.grid_height = (0, _react.useMemo)(() => {
    let res = config.nodes.reduce((prev, curr) => {
      return {
        row_height: prev.row_height + curr.row_height
      };
    }, {
      row_height: 0
    });
    return res.row_height;
  }, []);

  const onDateIptClick = e => {
    let name = e.currentTarget.getAttribute('data-name');

    if (!!showCalendar && showCalendar === name) {
      setShowCalendar(false);
    } else {
      switch (name) {
        case 'start-date':
          setShowCalendar('start-date');
          break;

        case 'end-date':
          setShowCalendar('end-date');
          break;
      }
    }
  };

  const onDateSelect = value => {
    const f_value = (0, _dayjs.default)(value);

    switch (showCalendar) {
      case 'start-date':
        if (f_value.isSame(f_start_date, 'd')) {
          setStartDate(f_start_date.toDate());
          break;
        }

        if (f_value.isBefore(endDate, 'd')) {
          setStartDate(value);
          break;
        }

        break;

      case 'end-date':
        if (f_value.isSame(f_end_date, 'd')) {
          setEndDate(f_end_date.toDate());
          break;
        }

        if (f_value.isAfter(startDate, 'd')) {
          setEndDate(f_value.endOf('day').toDate());
          break;
        }

        break;
    }

    setShowCalendar(false);
  };

  return (0, _jsxRuntime.jsxs)("div", {
    className: _s('gantt'),
    style: {
      width: "".concat(width, "px")
    },
    children: [(0, _jsxRuntime.jsxs)("div", {
      className: _s('gantt-chart'),
      style: {
        height: "".concat(height - _config.DRAG_SLIDER_HEIGHT, "px")
      },
      children: [(0, _jsxRuntime.jsxs)("header", {
        className: _s('header'),
        children: [(0, _jsxRuntime.jsx)("h1", {
          className: _s('h1'),
          style: {
            height: "".concat(_config.TITLE_HEIGHT, "px"),
            lineHeight: "".concat(_config.TITLE_HEIGHT, "px")
          },
          children: config.title
        }), (0, _jsxRuntime.jsxs)("div", {
          className: _s('date-picker-wrap'),
          children: [(0, _jsxRuntime.jsx)("div", {
            "data-name": "start-date",
            className: _s('date-ipt', 'start-date'),
            onClick: onDateIptClick,
            children: showCalendar === 'start-date' ? (0, _jsxRuntime.jsxs)("span", {
              children: [(0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "----"
              }), "/", (0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "--"
              }), "/", (0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "--"
              })]
            }) : (0, _dayjs.default)(startDate).format('YYYY-MM-DD')
          }), (0, _jsxRuntime.jsx)("div", {
            className: _s('sep-word'),
            children: "\u81F3"
          }), (0, _jsxRuntime.jsx)("div", {
            "data-name": "end-date",
            onClick: onDateIptClick,
            className: _s('date-ipt', 'end-date'),
            children: showCalendar === 'end-date' ? (0, _jsxRuntime.jsxs)("span", {
              children: [(0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "----"
              }), "/", (0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "--"
              }), "/", (0, _jsxRuntime.jsx)("em", {
                className: _s('ani-flash'),
                children: "--"
              })]
            }) : (0, _dayjs.default)(endDate).format('YYYY-MM-DD')
          })]
        })]
      }), (0, _jsxRuntime.jsx)(_ChartSvg.default, {
        showPercent,
        showStartPercent,
        startDate,
        endDate,
        data: config,
        columnWidth: columnWidth,
        msWidth: msWidth,
        svgWith: svgWith
      }), (0, _jsxRuntime.jsx)(_XAxisSvg.default, {
        showPercent,
        showStartPercent,
        startDate,
        endDate,
        svgWith: svgWith,
        msWidth: msWidth,
        data: config
      })]
    }), (0, _jsxRuntime.jsxs)("div", {
      className: _s('g-drag-container'),
      style: {
        marginLeft: "".concat(_config.MARGIN_LEFT, "px"),
        height: "".concat(_config.DRAG_SLIDER_HEIGHT, "px")
      },
      children: [(0, _jsxRuntime.jsx)(_SummarySvg.default, {
        chart_width: width - _config.MARGIN_LEFT,
        startDate,
        endDate,
        data: config
      }), (0, _jsxRuntime.jsx)(_DragSlider.default, {
        initShowPercent: config.showPercent,
        setShowPercent,
        initShowStartPercent: config.showStartPercent,
        setShowStartPercent,
        chart_width: width - _config.MARGIN_LEFT,
        clickJumpPercent: _config.CLICK_JUMP_PERCENT,
        callback: onDragging
      })]
    }), (0, _jsxRuntime.jsx)("div", {
      className: _s('calendar-wrap', !!showCalendar && 'show'),
      children: (0, _jsxRuntime.jsx)(_reactCalendar.default, {
        minDate: f_start_date.toDate(),
        maxDate: f_end_date.toDate(),
        value: showCalendar === 'start-date' ? startDate : showCalendar === 'end-date' ? endDate : null,
        onClickDay: onDateSelect,
        calendarType: "US"
      })
    })]
  });
};

var _default = GanttReact;
exports.default = _default;